summaryrefslogtreecommitdiff
path: root/src/include/taler_exchange_service.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/taler_exchange_service.h')
-rw-r--r--src/include/taler_exchange_service.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/include/taler_exchange_service.h b/src/include/taler_exchange_service.h
index 554d98bf5..15e51bc2a 100644
--- a/src/include/taler_exchange_service.h
+++ b/src/include/taler_exchange_service.h
@@ -837,13 +837,13 @@ TALER_EXCHANGE_reserve_status (struct TALER_EXCHANGE_Handle *exchange,
/**
- * Cancel a withdraw status request. This function cannot be used
+ * Cancel a reserve status request. This function cannot be used
* on a request handle if a response is already served for it.
*
* @param wsh the withdraw status request handle
*/
void
-TALER_EXCHANGE_reserve_status_cancel (struct TALER_EXCHANGE_ReserveStatusHandle *wsh);
+TALER_EXCHANGE_reserve_status_cancel (struct TALER_EXCHANGE_ReserveStatusHandle *rsh);
/* ********************* /reserve/withdraw *********************** */
@@ -837,13 +837,13 @@ TALER_EXCHANGE_reserve_status (struct TALER_EXCHANGE_Handle *exchange,
* on a request handle if a response is already served for it.
*
- * @param wsh the withdraw status request handle
+ * @param rsh the reserve status request handle
*/
void